API des unités
Commencer
Comme décrit dans la section Partage de données , DCP concerne entièrement les données, et les données envoyées à votre DMS par BRP sont aussi essentielles que les données du concessionnaire envoyées à BRP. Un élément de données essentiel est le catalogue d’unités de BRP.
L’API Units permet aux concessionnaires d’obtenir le dernier catalogue d’unités BRP dans leur DMS. Comme le catalogue d’unités est utilisé dans de nombreuses activités de concession, disposer du catalogue le plus récent dans votre DMS est bénéfique pour les concessionnaires de nombreuses façons, par exemple :
- La possibilité de référencer des numéros de modèle d’unité cohérents lors de discussions avec BRP.
- Une commande d’unités plus précise.
- Une meilleure connaissance des dernières modifications des unités.
En résumé, l’API Units est un élément central de votre intégration avec BRP.
L’API Units fournit trois types de requêtes :
- Obtenir le catalogue complet des unités.
- Obtenir le catalogue d’unités pour une gamme de produits et/ou une région spécifique.
- Obtenir les modifications apportées au catalogue d’unités après une date spécifiée.
- Obtenir les informations sur un modèle particulier.
Par où commencer ? Lisez ceci d’abord !
Avant de commencer à travailler sur cette API, vous devez lire les sections suivantes si vous ne les avez pas déjà consultées :
- Informations techniques pour des informations techniques générales sur l’API et les environnements.
- Authentification et informations d’identification pour plus de détails sur l’authentification et les identifiants.
- Processus de Certification pour plus de détails sur le processus de certification et Jira.
- Obtenir de l'aide pour plus de détails sur la façon d’obtenir de l’aide et Jira.
Quand appeler l’API
Pour les opérations du concessionnaire, utiliser un catalogue d’unités à jour est essentiel.
Vous devez appeler l’API Units au moins une fois par mois pour obtenir les dernières modifications !
Comme décrit dans la section Exigences fonctionnelles , vous devez appeler l’API Units chaque mois pour obtenir les changements des 30 derniers jours.
Cependant, il s’agit du minimum requis. Comme indiqué dans la section Obtenir les changements de la semaine dernière , vous pouvez appeler l’API Units quotidiennement pour obtenir les changements de la dernière semaine.
De cette façon, vous pouvez vous assurer que le concessionnaire dispose d’un catalogue de pièces à jour même si la mise à jour ne fonctionne pas un jour donné.
Les données de l’API Units sont mises à jour quotidiennement et sont finalisées à 4h00, heure de l’Est (ET). Le meilleur moment pour appeler l’API Units afin de mettre à jour votre DMS est donc après 4h00 ET.
Comment appeler l'API
La Référence de l'API section indique que l'API des unités offre deux services : l'un pour obtenir le catalogue complet des unités ou les dernières modifications, et l'autre pour obtenir une unité spécifique.
Lorsque le concessionnaire recherche un numéro de modèle spécifique, le service pour obtenir une unité spécifique est appelé selon les besoins. En d'autres termes, le service est appelé manuellement.
Comme décrit dans la Exigences fonctionnelles section, le service pour récupérer le catalogue complet des unités ou les dernières modifications doit être automatisé.
Le concessionnaire n’a pas à intervenir pour mettre à jour quotidiennement le catalogue des unités.
Informations techniques
Caractéristiques
Type d'API | Type DSP | Version DCP | Complexité |
|---|---|---|---|
Obtenir des données de BRP | DMS | V3 - International | Faible |
Envoyer des données à BRP | CRM | V4 - Amérique du Nord | Un peu plus |
Transaction avec BRP | | | Un peu plus encore |
Authentification
L'API utilise Authentification de l'application.
Vous avez besoin d'un jeton d'accès valide avant d'appeler cette API ou vous devez les appeler API d'authentification d'application pour en obtenir un.
Le jeton d'accès est valide pendant 30 minutes ! (1799 secondes)
URL de base
Test | https://qa-cloud-api.brp.com/dcp/v4 |
|---|---|
Production | https://cloud-api.brp.com/dcp/v4 |
Ressource : Unité
Lorsqu’elle est appelée pour demander le catalogue complet des unités ou les dernières modifications, l’API Units renvoie un tableau de Unit ressources. Chaque Unit ressource, présentée ci‑dessous, contient toutes les informations relatives à une unité.
Lorsqu'elle est appelée pour obtenir une unité spécifique, l'API Units renvoie une seule Unité ressource.
Représentation JSON
{
"model_no": "00010PA00",
"model_name": "PWC RXT X 300 AUD YL IBR IDF 23",
"product_line": "PWC",
"brand": "seadoo",
"segment": "Performance",
"sales_status_code": "U8",
"last_change_date": "2024-11-27T20:19:03Z",
"product_last_change_date": "2024-11-27T20:19:03Z",
"model_year": "2023",
"characteristics": {
"color": "Millenium Yellow",
"color_icon": "https://brp.com/content/dam/global/en/sea-doo/my23/unit-color-swatches/Millenium-Yellow.png",
"engine": "1630 ACE™- 300",
"engine_power_cc": "1630 cc",
"cylinders": "3",
"engine_power_hp": "300 hp",
"engine_code": "300",
"seats": "3",
"warranty_extended": "BRP limited warranty covers the watercraft for one year.",
"fuel_capacity": "18.5 US gal / 70 L",
"length": "135.9\" / 345.1 cm",
"width": "49.4\" / 125.5 cm",
"height": "45.2\"/ 114.7 cm",
"weight": "829 lb / 376 kg",
"package_label": "RXT-X 300",
"model_description": "RXT-X 300 Tech Package, iDF, iBR, 10PA, Millenium Yellow, 2023"
},
"image_information": [
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my23/studio/performance/side/SEA-MY23-RXT-X-SS-300-Eclipse-Black-00010PC00-Studio-RSide-NA.png",
"image_type": "defaultModelImage"
},
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my23/studio/performance/side/SEA-MY23-RXT-X-SS-300-Eclipse-Black-00010PC00-Studio-RSide-NA.png",
"image_type": "defaultPackageImage"
},
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my23/studio/performance/SEA-MY23-RXT-X-SS-300-Millenium-Yellow-00010PA00-Studio-34FR-NA.png",
"image_type": "packageImage"
}
],
"pricings": [
{
"price_type": "freight",
"currency": "USD",
"region": "US",
"price_valid_from": "2022-11-11T00:00:00Z",
"price_valid_to": "9999-12-31T00:00:00Z",
"price": 550,
"price_last_change_date": "2023-06-15T13:50:20.000Z"
},
{
"price_type": "surcharge",
"currency": "USD",
"region": "US",
"price_valid_from": "2022-11-11T00:00:00Z",
"price_valid_to": "9999-12-31T00:00:00Z",
"price": 615,
"price_last_change_date": "2023-06-15T19:04:07.000Z"
},
{
"price_type": "retail",
"currency": "USD",
"region": "US",
"price_valid_from": "2022-08-07T00:00:00Z",
"price_valid_to": "9999-12-31T00:00:00Z",
"price": 18499,
"price_last_change_date": "2024-11-27T20:19:03Z"
},
{
"price_type": "dealer",
"currency": "USD",
"region": "US",
"price_valid_from": "2022-08-07T00:00:00Z",
"price_valid_to": "9999-12-31T00:00:00Z",
"price": 16279,
"price_last_change_date": "2024-11-27T20:19:03Z"
}
],
"documents": {
"model_description": [
"The RXT-X pairs a high octane attitude with exceptional confidence and convenience, making it the ultimate offshore performance watercraft."
],
"spec_sheet": [
"https://brp.com/content/dam/global/en/sea-doo/my23/documents/specs-sheets/en/SEA-MY23-PERF-RXT-X-SPEC-DPS-ENNA_LR.pdf"
],
"package_description": [
"The ultimate in offshore performance watercraft. The RXT-X brings 300 HP of adrenaline-filled fun to every adventure. The revolutionary hull design and Ergolock seating system offer maximum control and confidence in any conditions."
],
"highlights": [
"Tech Package: BRP Audio Premium system & full color display",
"The most powerful engine in the Sea-Doo lineup",
"Industry leading stability and control",
"Up to 3 passengers"
],
"comparison_sheet": ""
}
}Propriétés
Property | Type | Definition | Notes |
|---|---|---|---|
model_no | string | Code that uniquely identifies a unit model. | Length:9 |
model_name | string | Model name/description. | Max Length:50 |
product_line | string | Code that uniquely identifies the product line. Refer to the Product Lines table below. | Length: 3 |
brand | string | The brand of the model. One of:
| |
segment | string | The segment of a specific unit. Example:
| Max Length:15
|
sales_status_code | string | string Code that identifies the sellable status of the unit. Refer to the Sales Status Code table below. | |
last_change_date | string | Last date and time when this resource has changed | Format: YYYY-MM-DDTHH:MM:SSZ |
product_last_change_date | string | The last date the product was updated. | Format: YYYY-MM-DDTHH:MM:SSZ |
model_year | string | Model year of the unit. |
|
characteristics | Object | The unit characteristics | |
characteristics.color | string | Color description of the unit. | |
characteristics.color_icon | string | A URL displaying an icon showing the shade of color for the unit. | |
characteristics.engine | string | Engine characteristics. | |
characteristics. engine_power_cc | string | The volume displaced by each piston moves from the bottom dead center to the top dead center. This is for all pistons in total. This value is expressed in cubic centimeters. | Max Length: 25 |
characteristics.cylinders | string | Number of cylinders in the engine. | Max Length: 3 |
characteristics. engine_power_hp | string | Engine power in horsepower. | Max Length: 25 |
characteristics.engine_code | string | The code for the model engine. | Max Length: 25 |
characteristics.seats | string | The number of seats in the unit. | Max Length: 3 |
characteristics. warranty_extended | string | The extended warranty coverage for the unit. | Max Length: 50 |
characteristics.fuel_capacity | string | The fuel capacity for the unit is represented in Liters and Gallons. | Max Length: 25 |
characteristics.length | string | The length of the unit is in centimeters and inches. | Max Length: 25 |
characteristics.width | string | The width of the unit is in centimeters and inches. | Max Length: 25 |
characteristics.height | string | The height of the unit is in centimeters and inches. | Max Length: 25 |
characteristics.weight | string | The weight of the unit is in kilograms and pounds. | Max Length: 25 |
characteristics.package_label | string | The package label. | |
characteristics.model_description | string | The complete model description, including the SKU, color, and model year. | |
image_information | List of objects | Image information for the unit. |
|
image_information.image_url | string | Link to the image of the unit. |
|
image_information. image_type | string | The type of image:
|
|
pricings | List of objects | List of the different prices |
|
pricings.region | string | The region where the price is valid. See the table Regions and Currencies below. | Max Length: 5 |
pricings.price_type | string | Code that identifies a type of price. One of:
| * For a Switch product, the dealer and retail prices include the trailer's dealer and retail prices. |
pricings.price_valid_from | string | The date at which the price becomes active. | Format: YYYY-MM-DDTHH:MM:SSZ |
pricings.price_valid_to | string | The date up to which the price remains active. | Format: YYYY-MM-DDTHH:MM:SSZ |
pricings.price | number | Price, excluding taxes, for one unit. | |
pricings.currency | string | Currency in which the price is provided. See the table Regions and Currencies below. | |
price_last_change_date | string | Last date and time at which this resource has changed. | Format: YYYY-MM-DDTHH:MM:SSZ |
documents | List of objects | Unit description and links to related documents. | |
documents. model_description | string | The description of a model in a short sentence. | |
documents.spec_sheet | string | Link to the full specification sheet in PDF format. | |
documents. package_description | string | The description of the unit on the package. | |
documents.highlights | string | Description of the major highlights included in the unit. | |
documents. comparison_sheet | string | The link to the comparison sheet highlights the differences between the BRP and the major competitor units. | |
trailer | object | ❗ Only for the Switch products. Description of the trailer sold with the Switch. | |
product_code | string | | |
product_descr | string | | |
pricings | List of objects | List of the different prices | |
pricings.region | string | The region where the price is valid. See the table Regions and Currencies below. | Max Length: 5 |
pricings.price_type | string | Code that identifies a type of price. One of:
| |
pricings.price_valid_from | string | The date at which the price becomes active. | Format: YYYY-MM-DDTHH:MM:SSZ |
pricings.price_valid_to | string | The date up to which the price remains active. | Format: YYYY-MM-DDTHH:MM:SSZ |
pricings.price | number | Price, excluding taxes, for one trailer. | |
pricings.currency | string | Currency in which the price is provided. See the table Regions and Currencies below. | |
price_last_change_date | string | Last date and time at which this resource has changed. | Format: YYYY-MM-DDTHH:MM:SSZ |
Code de statut des ventes
Clé | Valeur | Description |
|---|---|---|
U1 | Formulaire | L’unité est vendable et peut être commandée via le formulaire de commande dans OMS. |
U2 | Ajouter/Modifier | L’unité est vendable et peut être commandée via le formulaire de commande, une commande additionnelle ou une commande de modification dans OMS. |
U3 | Complet | L’unité est vendable et peut être commandée via une commande additionnelle ou une commande de modification dans OMS. |
U4 | Formulaire/Ajout | L’unité est vendable et peut être commandée via le formulaire de commande et une commande additionnelle dans OMS. |
U5 | Formulaire/Modification | L’unité est vendable et peut être commandée via le formulaire de commande et une commande de modification dans OMS. |
U6 | Ajout | L’unité est vendable et peut être commandée via une commande additionnelle dans OMS |
U7 | Commande de modification | L’unité est vendable et peut être commandée via une commande de modification dans OMS. |
U8 | Affichage | L’unité ne peut pas être commandée auprès de BRP mais est affichée dans OMS. |
UI | Inactif | L’unité ne peut pas être commandée auprès de BRP et n’est pas affichée dans OMS. |
Ressource : Liste des unités
Lorsqu’elle est appelée pour demander le catalogue complet des unités ou les dernières modifications, l’API Units renvoie un tableau de ressources Unit .
Les réponses de retour contiennent deux objets qui vous aident à naviguer dans les pages du catalogue des unités.
Représentation JSON
{
"items": [
{
List of Units resources
}
],
"links": {
"previous": null,
"next": "https://cloud-api.brp.com/dcp/v4/units?language=en-US&page=2&limit=200"
},
"meta": {
"total_records": 9999,
"total_pages": 87,
"current_page": 2,
"limit": 200
}
}Propriétés
Propriété | Type | Définition |
|---|---|---|
éléments | Liste d’objets | Liste des ressources Unit qui sont retournées. |
liens | objet | Liens de pagination. |
liens.précédent | chaîne | URL à utiliser pour récupérer la page précédente. NULL s’il n’y a pas de page précédente. |
liens.suivant | chaîne | URL à utiliser pour récupérer la page suivante. NULL s’il n’y a pas de page suivante. |
métadonnées | objet | Statistiques de la requête. |
métadonnées.total_enregistrements | nombre | Le nombre d’enregistrements retournés par la requête. |
métadonnées.total_pages | nombre | Le nombre de pages calculé en utilisant la limite. |
métadonnées.page_actuelle | nombre | Le numéro de la page actuelle ou le numéro de page demandé. |
métadonnées.limite | nombre | Limite provenant des paramètres de la requête. |
Liens
Le Liens objet peut être utilisé pour naviguer dans les pages renvoyées par l'API Units.
Lorsqu’un lien n’est pas NULL, il peut être utilisé pour accéder à la page précédente ou suivante. Cela simplifie la navigation entre les pages, car vous n’avez pas à enregistrer votre requête : l’URL du lien contient les paramètres de requête que vous avez fournis ainsi que les paramètres par défaut pour ceux que vous n’avez pas fournis.
Métadonnées
L’objet Meta fournit des statistiques sur le nombre de ressources Unit renvoyées par votre requête et sur le nombre de pages attendues.
Ces informations peuvent être utiles pour le diagnostic et pour vérifier que toutes les ressources Unit ont été reçues.
Limites et contraintes
Format numérique
Tous les champs numériques avec décimales utilisent le point(.) comme séparateur décimal. La virgule (,) n’est PAS prise en charge comme séparateur décimal.
Années de modèle disponibles
Le catalogue des unités contient des informations sur l’année de modèle 2023 et au-delà. Vous ne trouverez pas d’informations sur un modèle 2017.
Aussi, le catalogue des unités inclut uniquement les 10 dernières années de modèle.
👉 Une année de modèle BRP est une année dans le futur (comme pour les fabricants automobiles). Cela signifie que l’année de modèle 2026 sera disponible en 2025.
Quand votre DMS appelle l’API Units en 2034, lorsque l’année de modèle est 2036, il recevra des informations sur les années de modèle 2025 à 2035.
Comprendre les unités
Code de statut de vente
Puisque le concessionnaire ne peut pas commander d’unités via une API DCP, les codes de statut de vente des unités, listés dans le Code de statut de vente dans le tableau ci‑dessus, sont fournis uniquement à titre informatif.
Cependant, les unités avec le code de statut de vente UI ne sont pas vendables et ne sont pas affichées dans l’OMS, donc il est préférable de ne pas afficher ces unités dans votre DMS.
Images du produit
Vous verrez généralement des liens vers 3 images pour chaque unité retournée dans la réponse, comme illustré ci‑dessous.
"image_information": [
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-NoSS-M170-Purple-Potion-00030SG00-Studio-RSIDE-CU.png",
"image_type": "defaultModelImage"
},
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-NoSS-M170-Purple-Potion-00030SG00-Studio-RSIDE-CU.png",
"image_type": "defaultPackageImage"
},
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-Integrated100W-M170-Teal-Blue-Metallic-00030SD00-Studio-34FR-CU.png",
"image_type": "packageImage"
}
],L’image du forfait ("image_type": "packageImage") est la plus proche de l’apparence réelle de l’unité et doit être affichée en premier.
Si l’image du forfait n’est pas disponible, l’defaultPackageImage doit être affichée. Et, comme vous pouvez vous en douter, si l’defaultPackageImage n’est pas disponible, l’defaultModelImage doit être affichée.
Examinons un exemple utilisant un produit Sea-Doo, le GTI SE 170. Ce modèle possède 3 codes de produit.
Code Produit | Description | Couleur |
|---|---|---|
00030SG00 | GTI SE 170 | Violet Minuit |
00030SA00 | GTI SE 170 | Bleu Sarcelle / Vert Manta |
00030SD00 | GTI SE 170 (Système Audio) | Bleu Sarcelle / Vert Manta |
Les deux premiers codes produit correspondent au même modèle dans des couleurs différentes. Le troisième produit inclut un système audio supplémentaire.
Si vous obtenez le defaultPackageImage ou le defaultModelImage pour le code produit 00030SD00 en utilisant le lien https://brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-NoSS-M170-Purple-Potion-00030SG00-Studio-RSIDE-CU.png, vous obtenez ceci.

Si vous obtenez le packageImage pour le même code produit en utilisant le lien https://www.brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-Integrated100W-M170-Teal-Blue-Metallic-00030SD00-Studio-34FR-CU.png, vous obtenez ceci.

Le packageImage est bien plus intéressant puisqu’il montre l’unité dans la bonne couleur et avec les haut-parleurs ajoutés.
Vous pouvez voir la différence en regardant le packageImage pour le code produit 00030SA00 qui est de la même couleur mais n’a pas les haut-parleurs.

Pourquoi la région US-AK ?
La région US-AK est la même que la région US , à une exception près : la valeur du prix du fret .
👉 Il est important d’afficher le bon prix du fret pour les concessionnaires situés en Alaska.
Les produits Switch et leurs remorques
Les pontons Switch font partie de la gamme de produits Sea-Doo. Ils ont la particularité d’être toujours vendus avec une remorque.
Par exemple, le Switch Cruise Limited 21 - 230 hp sur le site de BRP inclut une remorque.

Pour les produits Switch, la réponse de l'API Units inclut des informations sur la remorque, y compris les prix de la remorque.
t👉 Pour les produits Switch, lorsqu'une remorque est disponible, les prix revendeur et au détail de la remorque sont ajoutés aux prix revendeur et au détail du Switch.
Référence de l'API
curl --location 'https://cloud-api.brp.com/dcp/v4/units?last_change_date=2024-06-01&product_line=SNO®ion=US&limit=3' \
--header 'Authorization: Bearer REPLACE_ME' curl --location 'https://cloud-api.brp.com/dcp/v4/unit/0001BRA00?region=US' \
--header 'Authorization: Bearer REPLACE_ME' Tableaux de référence
Langues
Langue en code de langue ISO (ISO-639-1 + ISO 3166-1)
Format : xx-XX
xx : code de langue en minuscules
XX : code pays en majuscules
Valeurs de code de langue prises en charge
Code | Langue |
|---|---|
de | Allemand |
en | Anglais |
es | Espagnol |
fi | Finnois |
fr | Français |
it | Italien |
nl | Néerlandais |
no | Norvégien |
pt | Portugais (Brésil) |
sv | Suédois |
Gammes de produits
Clé | Valeur |
|---|---|
2WV | Véhicules à deux roues |
3WV | Véhicules à trois roues |
ATV | Véhicules tout-terrain |
PTN | Bateaux pontons |
PWC | Motomarines |
SNO | Motoneiges |
SSV | Véhicules côte à côte |
Régions et devises
Code | Pays | Région | Devise | Description |
|---|---|---|---|---|
CA | Canada | | CAD | Toute le Canada, y compris toutes les provinces. |
US | États-Unis | | USD | Tous les États-Unis. |
US-AK | États-Unis | Alaska | USD | Seulement l'État de l'Alaska aux États-Unis. |
Comment faire
Cette section fournit des informations sur la manière d'obtenir des résultats spécifiques avec l'API Units.
Obtenir la première page
Obtenez la première page du catalogue complet des unités. Dans ce scénario, la demande est effectuée pour les concessionnaires américains.
La charge utile de la réponse contient la liste des ressources Unit, l’objet links et l’objet meta. La propriété links.previous est NULL car il s’agit de la première page. La propriété links.next contient l’URL de la page suivante.
curl --location 'https://cloud-api.brp.com/dcp/v4/units?region=US&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Obtenir la page suivante
Obtenez la page suivante du catalogue complet en utilisant l’URL links.next trouvée dans la charge utile de la réponse.
La charge utile de la réponse contient la liste des ressources Unit, l’objet links et l’objet meta. La propriété links.previous contient l’URL de la première page. La propriété links.next contient l’URL de la page suivante.
curl --location 'https://cloud-api.brp.com/dcp/v4/units?region=US&language=ca-EN&page=2&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Obtenir la dernière page
Obtenez la page suivante du catalogue complet en utilisant l’links.next URL trouvée dans la charge utile de la réponse.
La charge utile de la réponse contient la liste des ressources Unit, l’objet links et l’objet meta. La propriété links.previous contient l’URL de la page précédente. La propriété links.next est NULL car il s’agit de la dernière page.
curl --location 'https://cloud-api.brp.com/dcp/v4/units?region=US&language=en-US&limit=2&page=1214' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Obtenir les modifications de la semaine dernière
Obtenez la première page des modifications apportées au catalogue des unités pour la région canadienne.
curl --location 'https://cloud-api.brp.com/dcp/v4/units?region=CA&last_change_date=2024-12-01&page=1&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtenir les produits pour une année modèle
Obtenir une ligne de produits spécifique et une année modèle pour la région des États-Unis.
curl --location 'https://qa-cloud-api.brp.com/dcp/v4/units?region=US&product_line=PWC&language=us-EN&model_year=2024&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtenir des produits pour une marque
Obtenir une marque et une année-modèle spécifiques pour le Canada.
curl --location 'https://qa-cloud-api.brp.com/dcp/v4/units?region=CA&language=us-EN&brand=seadoo&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtenir des produits pour une marque et une année modèle
Obtenir une marque et une année modèle spécifiques pour le Canada.
curl --location 'https://qa-cloud-api.brp.com/dcp/v4/units?region=CA&language=us-EN&brand=seadoo&model_year=2025&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtenir des produits pour une marque et une gamme de produits
Obtenir une marque et une gamme de produits spécifiques pour le Canada.
❗ Si la marque demandée ne contient pas la ligne de produits demandée, rien n'est renvoyé ❗
Si vous demandez la marque seadoo et la ligne de produits SNO, rien n'est renvoyé.
curl --location 'https://qa-cloud-api.brp.com/dcp/v4/units?region=CA&language=us-EN&brand=canam-offroad&product_line=ATV&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtenir une unité
Obtenir une unité spécifique pour la région Alaska des États-Unis.
La réponse montre le fret prix pour la région US-AK. Cela est dû au fait que les coûts de fret en Alaska diffèrent de ceux des autres régions des États-Unis.
curl --location 'https://cloud-api.brp.com/dcp/v4/unit/000B2PA00?region=US-AK' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Obtenir une unité à partir d’un VIN
Nous avons probablement constaté que l'API Units fonctionne avec des numéros de modèle (codes produit). Le concessionnaire n'a généralement pas de numéro de modèle mais un numéro de série (VIN).
Comment obtenir les informations de l’unité à partir du NIV ?
Appelez l’API de spécifications d'unité pour obtenir le numéro de modèle correspondant au NIV.
À partir de la réponse de l’API des spécifications de l’unité, extrayez le numéro_modèle et utilisez-le pour appeler l’API des unités.
Obtenir le Spécifications de l’unité
curl --location 'https://cloud-api.brp.com/dcp/v4/unit/3JB3GA449RJ000623/specifications?language=en-US' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtenir l’unité
curl --location 'https://cloud-api.brp.com/dcp/v4/unit/0001BRA00?region=US' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtenir une unité Switch
Obtenir une unité Switch spécifique pour la région des États-Unis.
curl --location 'https://cloud-api.brp.com/dcp/v4/unit/00041PJ00?region=US' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Gestion des erreurs
Cette section présente divers scénarios d’appels incorrects ou erronés, qui entraînent des messages d’erreur et des résultats incorrects.
400 Mauvaise requête
Le code d’état 400 est généralement observé lors du développement et de l’intégration et ne devrait pas être reçu lors des opérations normales. La réponse renvoyée contient les informations nécessaires pour corriger le problème.
De nombreux problèmes peuvent provoquer un code d’état 400 ; les plus courants sont dans le tableau ci-dessous.
Réponse | Résolution |
|---|---|
Renvoyé si la région n’est pas valide. {
"status": "400",
"id": "rrt-0f82577f1ea003b72-c-ea-3940242-6823134-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "échec de la validation de la requête",
"payload": {
"details": [
{
"message": "La valeur de l’instance (\"eg\") est introuvable dans l’énumération (valeurs possibles : [\"CA\",\"US\",\"US-AK\"]): []"
}
]
}
}
} | Assurez-vous d’appeler l’API avec une région valide. |
Format de date de dernière modification invalide. {
"status": "400",
"id": "rrt-007c4ae418b4c128f-b-ea-3013143-8196485-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "échec de la validation de la requête",
"payload": {
"details": [
{
"message": "La chaîne \"2024-09-31\" est invalide selon le format de date demandé yyyy-MM-dd: []"
}
]
}
}
} | Modifiez le format de date pour utiliser YYYY-MM-DD. |
Renvoyé si le format de langue n’est pas valide. {
"status": "400",
"id": "rrt-007c4ae418b4c128f-b-ea-3013144-8202243-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "échec de la validation de la requête",
"payload": {
"details": [
{
"message": "La regex ECMA 262 \"^[a-z]{2}-[A-Z]{2}$\" ne correspond pas à la chaîne d’entrée \"eg-CAI\": []"
}
]
}
}
} | Le format de langue valide est le suivant Format : xx-XX xx : code de langue en minuscules XX : code pays en majuscules Un format de langue valide doit être saisi pour produire une réponse correcte. |
Paramètre de région manquant. {
"status": "400",
"id": "rrt-04975a7274072003d-d-ea-3824655-7029451-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "échec de la validation de la requête",
"payload": {
"details": [
{
"message": "Le paramètre de requête 'region' est requis sur le chemin '/units' mais est introuvable dans la requête.: []"
}
]
}
}
} | Le paramètre région est obligatoire. |
401 Non autorisé
Le code d’erreur 401 Unauthorized est renvoyé lorsque vous essayez d’appeler l’API avec un access_token.
Vous devez obtenir un nouveau access_token en appelant le API d'authentification d'application.
Le code d’erreur 401 Unauthorized est également renvoyé si vous n’avez pas demandé l’accès à l’API en créant un ticket dans le Jira du DCP.
Lorsque vous êtes prêt à commencer à travailler sur une API, vous devez créer un ticket de certification dans Jira, comme décrit dans la section Activités de certification avec Jira.
Si vous avez déjà commencé à travailler sur une API et perdu l’accès, créez un ticket de support comme décrit dans la section Ouvrir un ticket de support.
404 Introuvable
Le code d’état 404 Not Found est renvoyé lorsque le numéro de modèle (code produit) est introuvable.
{
"status": "404",
"id": "rrt-0aa500db076dc9eed-d-ea-1328974-8146403-1.1",
"title": "not_found",
"meta": {
"service": "004",
"detail": "The product code provided was not found."
}
}Le concessionnaire a peut‑être commis une erreur en saisissant le numéro de pièce. Vous devez signaler l’erreur à l’utilisateur afin qu’il puisse réessayer.
Exigences du DSP
Exigences fonctionnelles
ID | Type | Exigence |
|---|---|---|
1 | Obligatoire | L’API Units doit être automatiquement appelée chaque mois pour obtenir les modifications du catalogue des 30 derniers jours. ❗ Aucune action manuelle du concessionnaire ne doit être nécessaire pour mettre à jour le catalogue dans son DMS ❗ |
2 | Obligatoire | Le catalogue complet des unités doit être mis à disposition du concessionnaire. L’API Units doit être appelée au moins une fois pour récupérer le catalogue complet des unités. |
3 | Obligatoire | Le concessionnaire doit pouvoir rechercher un numéro de produit spécifique dans votre DMS, et le résultat doit être affiché à l’écran. |
4 | Obligatoire | Le concessionnaire doit pouvoir afficher l’image de l’unité, la couleur, les caractéristiques, les spécifications techniques, les points forts et tous les documents disponibles. |
5 | Optionnel | Le concessionnaire peut obtenir le catalogue des unités pour une année-modèle spécifique. |
6 | Optionnel | Le concessionnaire peut obtenir le catalogue des unités pour une ligne de produits spécifique. |
7 | Optionnel | Le concessionnaire peut rechercher et naviguer dans le catalogue des unités, filtrer le catalogue par ligne de produits et rechercher du texte dans la description. |
Activités de certification
Cette section présente toutes les activités de certification et les validations qui doivent être réalisées pour certifier l’API.
Validations
Les tests répertoriés dans le tableau ci-dessous doivent être réalisés avec succès dans l’environnement de test avant que vous puissiez commencer la phase pilote concessionnaire.
👉 Pour la phase de test, votre DMS doit appeler l’API Units chaque jour.
Une fois le pilote concessionnaire terminé, la configuration de votre DMS peut être modifiée pour appeler l’API Units mensuellement si vous le préférez.
ID | Test | Résultat attendu |
|---|---|---|
1 | Le catalogue complet des unités est chargé et le DMS affiche les unités. | Le catalogue complet des unités est chargé dans le DMS. |
2 | Les informations de l’unité sont visibles | Le DMS affiche l’image de l’unité, la couleur, les caractéristiques, les spécifications techniques, les points saillants et tous les documents disponibles. |
3 | Recherche d’un numéro de produit spécifique :
| Un numéro de produit spécifique peut être recherché depuis le DMS, et le résultat est affiché. |
4 | Récupérer les unités pour la gamme de produits PWC et l’année-modèle 2025 | Charger ou actualiser le catalogue des unités pour une gamme de produits spécifique (PWC) et une année-modèle (2025). |
Pilote de concessionnaire
Le tableau ci-dessous décrit les paramètres et les validations du pilote concessionnaire.
👉 Pour la phase pilote concessionnaire, votre DMS doit appeler l’API Units quotidiennement.
Une fois le pilote concessionnaire terminé, la configuration de votre DMS peut être modifiée pour appeler l’API Units mensuellement si vous le souhaitez.
Paramètre | Valeur |
|---|---|
Environnement | Production |
Nombre de concessionnaires | 1 à 3 |
Durée | 1 semaine |
Validation 1 | Le catalogue des unités est mis à jour quotidiennement. |
Validation 2 | Le catalogue des unités est accessible au concessionnaire. |
Validation 3 | Un numéro de produit spécifique peut être recherché depuis le DMS, et le résultat est affiché. |
Postman
Cette section décrit ce qui est disponible dans Postman pour explorer l'API.
Environnements
Un environnement Postman est disponible pour essayer l'API Units. Cet environnement Postman contient des variables utilisées par les requêtes et est configuré pour se connecter à l'environnement de test.
Collections
La collection DMS - Units contient des exemples d’appels API pour obtenir le catalogue des unités ou une unité spécifique.